![Uni Wuerzburg - Data Driven Decisions](https://raw.githubusercontent.com/d3group/.github/refs/heads/main/assets/unilogo4c_combined.png)

# Foundry SDK
## Info

This repository contains the Foundry SDK, a collection of tools and utilities to help with the development of ETL and training pipelines.

For various documentations, please refer to the foundry-master repository: [Foundry Master](https://github.com/d3group/foundry-master)


## Contributing

If you’d like to contribute to this project, please check out the [Contribution Guide](./CONTRIBUTING.md).